@@ -44,8 +44,8 @@
 #define PAD 6
 
 enum {
-	ARG_0,
-	ARG_PRINT_CONFIG
+	PROP_0,
+	PROP_PRINT_CONFIG
 };
 
 static void gnome_print_dialog_class_init (GnomePrintDialogClass *class);
@@ -99,7 +99,7 @@ gnome_print_dialog_set_property (GObject      *object,
 	GnomePrintDialog *gpd = GNOME_PRINT_DIALOG (object);
 
 	switch (prop_id) {
-	case ARG_PRINT_CONFIG:
+	case PROP_PRINT_CONFIG:
 		new_config = g_value_get_pointer (value);
 		if (new_config) {
 			if (gpd->config)
@@ -126,7 +126,7 @@ gnome_print_dialog_class_init (GnomePrintDialogClass *class)
 
 	G_OBJECT_CLASS (class)->set_property = gnome_print_dialog_set_property;
 	g_object_class_install_property (G_OBJECT_CLASS (class),
-					 ARG_PRINT_CONFIG,
+					 PROP_PRINT_CONFIG,
 					 g_param_spec_pointer ("print_config",
 							       "Print Config",
 							       "Printing Configuration to be used",
@@ -302,7 +302,7 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 			gpd->job = gpd_create_job_page (gpd);
 			gtk_container_set_border_width (GTK_CONTAINER (gpd->job), 4);
 			gtk_widget_show (gpd->job);
-			l = gtk_label_new_with_mnemonic (_("_Job"));
+			l = gtk_label_new_with_mnemonic (_("Job"));
 			gtk_widget_show (l);
 			gtk_notebook_append_page (GTK_NOTEBOOK (gpd->notebook), gpd->job, l);
 		}
@@ -317,7 +317,7 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 		
 		gtk_box_pack_start (GTK_BOX (hb), gpd->printer, FALSE, FALSE, 0);
 		
-		l = gtk_label_new_with_mnemonic (_("P_rinter"));
+		l = gtk_label_new_with_mnemonic (_("Printer"));
 		gtk_widget_show (l);
 		
 		gtk_notebook_append_page (GTK_NOTEBOOK (gpd->notebook), hb, l);
@@ -327,7 +327,7 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 		gtk_container_set_border_width (GTK_CONTAINER (p), 4);
 		gtk_widget_show (p);
 		
-		l = gtk_label_new_with_mnemonic (_("Pap_er"));
+		l = gtk_label_new_with_mnemonic (_("Paper"));
 		gtk_widget_show (l);
 		
 		gtk_notebook_append_page (GTK_NOTEBOOK (gpd->notebook), p, l);
